@@ -17,6 +17,7 @@ import sys
 
 import click
 import six
+import yaml
 
 
 __author__ = 'Kentaro Wada <www.kentaro.wada@gmail.com>'
@@ -47,15 +48,21 @@ def parse_todo(content):
             else:
                 raise ValueError
         elif line.startswith('## '):
-            section = line  # todo section
+            m = re.match('^## (.*)$', line)
+            section = m.groups()[0]
         elif line.startswith('- '):
             m = re.match('^- \[( |x)\] (.*)$', line)
             assert len(m.groups()) == 2
             done = m.groups()[0] == 'x'
-            text = m.groups()[1]
-            todos.append((text, done, section, []))
+            title = m.groups()[1]
+            todos.append({
+                'title': title,
+                'done': done,
+                'section': section,
+                'detail': [],
+            })
         else:
-            todos[-1][3].append(line)  # detail
+            todos[-1]['detail'].append(line)
 
     date = date or datetime.date.today()
 
@@ -67,30 +74,37 @@ def render_todo(date, todos, color=False):
     if color:
         date = click.style(date, 'green')
 
-    todo = []
-    for text, done, section, detail in todos:
+    content_todo = []
+    for todo in todos:
+        title = todo['title']
+        done = todo['done']
+        section = todo['section']
+        detail = todo['detail']
+
         if section is not None:
+            section = '## {:s}'.format(section)
             if color:
                 section = click.style(section, 'blue')
-            if section not in todo:
-                todo.append('')
-                todo.append(section)
-                todo.append('')
+            if section not in content_todo:
+                content_todo.append('')
+                content_todo.append(section)
+                content_todo.append('')
+
         cross = 'x' if done else ' '
         if color and not done:
-            text = click.style(text, underline=True)
-        todo.append('- [{:s}] {:s}'.format(cross, text))
+            title = click.style(title, underline=True)
+        content_todo.append('- [{:s}] {:s}'.format(cross, title))
+
         if detail:
-            todo.append('')
-            todo.append('\n'.join(detail))
-            todo.append('')
-    todo = '\n'.join(todo)
+            content_todo.append('')
+            content_todo.append('\n'.join(detail))
+            content_todo.append('')
 
     content = '''\
 {date}
 {todo}
 '''
-    content = content.format(date=date, todo=todo)
+    content = content.format(date=date, todo='\n'.join(content_todo))
 
     return content
 
@@ -156,21 +170,20 @@ def _archive(push=True):
 
     todos_remain = []
     todos_archive = []
-    for todo in todos[:]:
-        text, done, section, detail = todo
-        if done:
+    for todo in todos:
+        if todo['done']:
             todos_archive.append(todo)
         else:
             todos_remain.append(todo)
-    content_archive = render_todo(date, todos_archive)
+    del todos
 
     # archive
-    archive_dir = osp.join(CACHE_DIR, date.strftime('%Y'))
-    if not osp.exists(archive_dir):
-        os.makedirs(archive_dir)
-    archive_fn = osp.join(archive_dir, date.strftime('%Y-%m.md'))
-    print('Archiving completed TODO to: {:s}'.format(archive_fn))
-    open(archive_fn, 'a').write('\n\n' + content_archive)
+    data = []
+    archive_fn = osp.join(CACHE_DIR, 'archive.yaml')
+    if osp.exists(archive_fn):
+        data = yaml.load(open(archive_fn))
+    data.append({date.strftime('%Y-%m-%d'): todos_archive})
+    yaml.safe_dump(data, open(archive_fn, 'w'), default_flow_style=False)
 
     # main
     content_remain = render_todo(datetime.date.today(), todos_remain)
@@ -256,7 +269,7 @@ def cmd_edit():
 def cmd_open():
     _init()
     _archive()
-    readme_url = osp.join(osp.splitext(GITHUB_URL)[0], 'blob/master/README.md')
+    readme_url = osp.join(GITHUB_URL.rstrip('.git'), 'blob/master/README.md')
     readme_url += datetime.date.today().strftime('#%Y-%m-%d')
     cmd = '{cmd} {url}'.format(cmd=_get_open_cmd(), url=readme_url)
     print('Opening {:s}'.format(readme_url))
